==> vulkan4j-0.2.0-sources.jar: tech/icey/vk4j/datatype/VkImportAndroidHardwareBufferInfoANDROID.java <==
package tech.icey.vk4j.datatype;

import java.lang.foreign.*;
import static java.lang.foreign.ValueLayout.*;

import tech.icey.panama.IPointer;
import tech.icey.panama.NativeLayout;
import tech.icey.panama.annotation.*;
import tech.icey.panama.buffer.*;
import tech.icey.vk4j.bitmask.*;
import tech.icey.vk4j.datatype.*;
import tech.icey.vk4j.enumtype.*;
import tech.icey.vk4j.handle.*;
import static tech.icey.vk4j.Constants.*;
import static tech.icey.vk4j.enumtype.VkStructureType.*;

/// {@snippet lang=c :
/// typedef struct VkImportAndroidHardwareBufferInfoANDROID {
///     VkStructureType sType;
///     const void* pNext;
///     struct AHardwareBuffer* buffer;
/// } VkImportAndroidHardwareBufferInfoANDROID;}
///
/// @see <a href="https://registry.khronos.org/vulkan/specs/1.3-extensions/man/html/VkImportAndroidHardwareBufferInfoANDROID.html">VkImportAndroidHardwareBufferInfoANDROID</a>
public record VkImportAndroidHardwareBufferInfoANDROID(MemorySegment segment) implements IPointer {
    public VkImportAndroidHardwareBufferInfoANDROID(MemorySegment segment) {
        this.segment = segment;
        this.sType(VK_STRUCTURE_TYPE_IMPORT_ANDROID_HARDWARE_BUFFER_INFO_ANDROID);
    }

    public @enumtype(VkStructureType.class) int sType() {
        return segment.get(LAYOUT$sType, OFFSET$sType);
    }

    public void sType(@enumtype(VkStructureType.class) int value) {
        segment.set(LAYOUT$sType, OFFSET$sType, value);
    }

    public @pointer(comment="void*") MemorySegment pNext() {
        return segment.get(LAYOUT$pNext, OFFSET$pNext);
    }

    public void pNext(@pointer(comment="void*") MemorySegment value) {
        segment.set(LAYOUT$pNext, OFFSET$pNext, value);
    }

    public void pNext(@nullable IPointer pointer) {
        pNext(pointer == null ? MemorySegment.NULL : pointer.segment());
    }

    public @pointer(comment="void*") MemorySegment buffer() {
        return segment.get(LAYOUT$buffer, OFFSET$buffer);
    }

    public void buffer(@pointer(comment="void*") MemorySegment value) {
        segment.set(LAYOUT$buffer, OFFSET$buffer, value);
    }

    public void buffer(@nullable IPointer pointer) {
        buffer(pointer == null ? MemorySegment.NULL : pointer.segment());
    }

    public static VkImportAndroidHardwareBufferInfoANDROID allocate(Arena arena) {
        return new VkImportAndroidHardwareBufferInfoANDROID(arena.allocate(LAYOUT));
    }

    public static VkImportAndroidHardwareBufferInfoANDROID[] allocate(Arena arena, int count) {
        MemorySegment segment = arena.allocate(LAYOUT, count);
        VkImportAndroidHardwareBufferInfoANDROID[] ret = new VkImportAndroidHardwareBufferInfoANDROID[count];
        for (int i = 0; i < count; i++) {
            ret[i] = new VkImportAndroidHardwareBufferInfoANDROID(segment.asSlice(i * SIZE, SIZE));
        }
        return ret;
    }

    public static VkImportAndroidHardwareBufferInfoANDROID clone(Arena arena, VkImportAndroidHardwareBufferInfoANDROID src) {
        VkImportAndroidHardwareBufferInfoANDROID ret = allocate(arena);
        ret.segment.copyFrom(src.segment);
        return ret;
    }

    public static VkImportAndroidHardwareBufferInfoANDROID[] clone(Arena arena, VkImportAndroidHardwareBufferInfoANDROID[] src) {
        VkImportAndroidHardwareBufferInfoANDROID[] ret = allocate(arena, src.length);
        for (int i = 0; i < src.length; i++) {
            ret[i].segment.copyFrom(src[i].segment);
        }
        return ret;
    }

    public static final MemoryLayout LAYOUT = NativeLayout.structLayout(
        ValueLayout.JAVA_INT.withName("sType"),
        ValueLayout.ADDRESS.withName("pNext"),
        ValueLayout.ADDRESS.withName("buffer")
    );
    public static final long SIZE = LAYOUT.byteSize();

    public static final PathElement PATH$sType = PathElement.groupElement("sType");
    public static final PathElement PATH$pNext = PathElement.groupElement("pNext");
    public static final PathElement PATH$buffer = PathElement.groupElement("buffer");

    public static final OfInt LAYOUT$sType = (OfInt) LAYOUT.select(PATH$sType);
    public static final AddressLayout LAYOUT$pNext = (AddressLayout) LAYOUT.select(PATH$pNext);
    public static final AddressLayout LAYOUT$buffer = (AddressLayout) LAYOUT.select(PATH$buffer);

    public static final long OFFSET$sType = LAYOUT.byteOffset(PATH$sType);
    public static final long OFFSET$pNext = LAYOUT.byteOffset(PATH$pNext);
    public static final long OFFSET$buffer = LAYOUT.byteOffset(PATH$buffer);

    public static final long SIZE$sType = LAYOUT$sType.byteSize();
    public static final long SIZE$pNext = LAYOUT$pNext.byteSize();
    public static final long SIZE$buffer = LAYOUT$buffer.byteSize();
}

==> vulkan4j-0.2.1-sources.jar: tech/icey/vk4j/datatype/VkImportAndroidHardwareBufferInfoANDROID.java <==
package tech.icey.vk4j.datatype;

import java.lang.foreign.*;
import static java.lang.foreign.ValueLayout.*;

import org.jetbrains.annotations.Nullable;
import tech.icey.panama.IPointer;
import tech.icey.panama.NativeLayout;
import tech.icey.panama.annotation.*;
import tech.icey.panama.buffer.*;
import tech.icey.vk4j.bitmask.*;
import tech.icey.vk4j.datatype.*;
import tech.icey.vk4j.enumtype.*;
import tech.icey.vk4j.handle.*;
import static tech.icey.vk4j.Constants.*;
import static tech.icey.vk4j.enumtype.VkStructureType.*;

/// {@snippet lang=c :
/// typedef struct VkImportAndroidHardwareBufferInfoANDROID {
///     VkStructureType sType;
///     const void* pNext;
///     struct AHardwareBuffer* buffer;
/// } VkImportAndroidHardwareBufferInfoANDROID;}
///
/// @see <a href="https://registry.khronos.org/vulkan/specs/1.3-extensions/man/html/VkImportAndroidHardwareBufferInfoANDROID.html">VkImportAndroidHardwareBufferInfoANDROID</a>
public record VkImportAndroidHardwareBufferInfoANDROID(MemorySegment segment) implements IPointer {
    public VkImportAndroidHardwareBufferInfoANDROID(MemorySegment segment) {
        this.segment = segment;
        this.sType(VK_STRUCTURE_TYPE_IMPORT_ANDROID_HARDWARE_BUFFER_INFO_ANDROID);
    }

    public @enumtype(VkStructureType.class) int sType() {
        return segment.get(LAYOUT$sType, OFFSET$sType);
    }

    public void sType(@enumtype(VkStructureType.class) int value) {
        segment.set(LAYOUT$sType, OFFSET$sType, value);
    }

    public @pointer(comment="void*") MemorySegment pNext() {
        return segment.get(LAYOUT$pNext, OFFSET$pNext);
    }

    public void pNext(@pointer(comment="void*") MemorySegment value) {
        segment.set(LAYOUT$pNext, OFFSET$pNext, value);
    }

    public void pNext(@Nullable IPointer pointer) {
        pNext(pointer == null ? MemorySegment.NULL : pointer.segment());
    }

    public @pointer(comment="void*") MemorySegment buffer() {
        return segment.get(LAYOUT$buffer, OFFSET$buffer);
    }

    public void buffer(@pointer(comment="void*") MemorySegment value) {
        segment.set(LAYOUT$buffer, OFFSET$buffer, value);
    }

    public void buffer(@Nullable IPointer pointer) {
        buffer(pointer == null ? MemorySegment.NULL : pointer.segment());
    }

    public static VkImportAndroidHardwareBufferInfoANDROID allocate(Arena arena) {
        return new VkImportAndroidHardwareBufferInfoANDROID(arena.allocate(LAYOUT));
    }

    public static VkImportAndroidHardwareBufferInfoANDROID[] allocate(Arena arena, int count) {
        MemorySegment segment = arena.allocate(LAYOUT, count);
        VkImportAndroidHardwareBufferInfoANDROID[] ret = new VkImportAndroidHardwareBufferInfoANDROID[count];
        for (int i = 0; i < count; i++) {
            ret[i] = new VkImportAndroidHardwareBufferInfoANDROID(segment.asSlice(i * SIZE, SIZE));
        }
        return ret;
    }

    public static VkImportAndroidHardwareBufferInfoANDROID clone(Arena arena, VkImportAndroidHardwareBufferInfoANDROID src) {
        VkImportAndroidHardwareBufferInfoANDROID ret = allocate(arena);
        ret.segment.copyFrom(src.segment);
        return ret;
    }

    public static VkImportAndroidHardwareBufferInfoANDROID[] clone(Arena arena, VkImportAndroidHardwareBufferInfoANDROID[] src) {
        VkImportAndroidHardwareBufferInfoANDROID[] ret = allocate(arena, src.length);
        for (int i = 0; i < src.length; i++) {
            ret[i].segment.copyFrom(src[i].segment);
        }
        return ret;
    }

    public static final MemoryLayout LAYOUT = NativeLayout.structLayout(
        ValueLayout.JAVA_INT.withName("sType"),
        ValueLayout.ADDRESS.withName("pNext"),
        ValueLayout.ADDRESS.withName("buffer")
    );
    public static final long SIZE = LAYOUT.byteSize();

    public static final PathElement PATH$sType = PathElement.groupElement("sType");
    public static final PathElement PATH$pNext = PathElement.groupElement("pNext");
    public static final PathElement PATH$buffer = PathElement.groupElement("buffer");

    public static final OfInt LAYOUT$sType = (OfInt) LAYOUT.select(PATH$sType);
    public static final AddressLayout LAYOUT$pNext = (AddressLayout) LAYOUT.select(PATH$pNext);
    public static final AddressLayout LAYOUT$buffer = (AddressLayout) LAYOUT.select(PATH$buffer);

    public static final long OFFSET$sType = LAYOUT.byteOffset(PATH$sType);
    public static final long OFFSET$pNext = LAYOUT.byteOffset(PATH$pNext);
    public static final long OFFSET$buffer = LAYOUT.byteOffset(PATH$buffer);

    public static final long SIZE$sType = LAYOUT$sType.byteSize();
    public static final long SIZE$pNext = LAYOUT$pNext.byteSize();
    public static final long SIZE$buffer = LAYOUT$buffer.byteSize();
}
